﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Drawing;
using System.Text;

namespace SimpleSample
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Model> myDataList;
        public ObservableCollection<Model> MyDataList
        {
            get { return myDataList; }
            set
            {
                myDataList = value;
                OnPropertyChanged("MyDataList");
            }
        }

        private ChartColorCollection myColors;
        public ChartColorCollection MyColors
        {
            get { return myColors; }
            set
            {
                myColors = value;
                OnPropertyChanged("MyColors");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyname)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyname));
        }


        public ViewModel()
        {
            MyDataList = new ObservableCollection<Model>
            {
                new Model() { XValue = "T1", YValue = 10 },
                new Model() { XValue = "T2", YValue = 50 },
                new Model() { XValue = "T3", YValue = 8 },
                new Model() { XValue = "T4", YValue = 40 },
                new Model() { XValue = "T5", YValue = 65 },
                new Model() { XValue = "T6", YValue = 45 },
                new Model() { XValue = "T7", YValue = 70 },
                new Model() { XValue = "T8", YValue = 15 },
                new Model() { XValue = "T9", YValue = 85 },
                new Model() { XValue = "T10", YValue = 35 }
            };

            MyColors = new ChartColorCollection();

            foreach (var value in MyDataList)
            {
                if (value.YValue < 20)
                    MyColors.Add(Color.Red);
                else if (value.YValue > 21 && value.YValue < 60)
                    MyColors.Add(Color.Green);
                else
                    MyColors.Add(Color.Blue);
            }

        }

        public void UpdateData()
        {
            var data1 = new ObservableCollection<Model>
            {
                new Model() { XValue = "A", YValue = 40 },
                new Model() { XValue = "B", YValue = 50 },
                new Model() { XValue = "C", YValue = 20 },
                new Model() { XValue = "D", YValue = 40 },
                new Model() { XValue = "E", YValue = 35 },
            };

            var colors1 = new ChartColorCollection()
            {
                Color.Red,
                Color.YellowGreen,
                Color.Violet,
                Color.DarkBlue,
                Color.Aqua
            };

            MyDataList = data1;
            MyColors = colors1;
        }
    }

    public class Model
    {
        public double YValue
        {
            get;
            set;
        }
        
        public string XValue
        {
            get;
            set;
        }
    }
}
